==> fusenshi-0.7.5.tgz: fusenshi-0.7.5/src/include/serverlist.h <==
/*
 * $Id: serverlist.h,v 1.1 2004/04/01 08:52:40 daichi Exp $
 *
 * Copyright 2003- ONGS Inc. All rights reserved.
 * 
 * author: Masanori OZAWA (ozawa@ongs.co.jp)
 * version: $Revision: 1.1 $
 *
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions
 * are met:
 * 
 *   1. Redistributions of source code must retain the above copyright
 *      notice, this list of conditions and the following disclaimer.
 *   2. Redistributions in binary form must reproduce the above copyright
 *      notice, this list of conditions and the following disclaimer in the
 *      documentation and/or other materials provided with the distribution.
 * 
 * THIS SOFTWARE IS PROVIDED BY ONGS INC ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL ONGS INC OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 * The views and conclusions contained in the software and documentation are
 * those of the authors and should not be interpreted as representing official
 * policies, either expressed or implied, of the ONGS Inc.
 * 
 */

#ifndef ___SERVERLIST_H
#define ___SERVERLIST_H

#include "glib.h"

class ServerList {
public:
    /**
     * 󥹥ȥ饯
     */
    ServerList();

    /**
     * ǥȥ饯
     */
    ~ServerList();
    
    /**
     * ˥оɲäޤ
     * 
     * @param szUserName 桼̾
     * @param szHostName ۥ̾
     * @param szIPAddr IPɥ쥹
     */
    void add(Glib::ustring szUserName, Glib::ustring szHostName,
             Glib::ustring szIPAddr);
    
    /**
     * ޤ
     */
    void clear();
    
    /**
     * 桼̾ΰޤ
     */
    std::list<Glib::ustring>& getUserNameList();
    
    /**
     * ۥ̾ΰޤ
     */
    std::list<Glib::ustring>& getHostNameList();
    
    /**
     * IPɥ쥹ΰޤ
     */
    std::list<Glib::ustring>& getIPAddrList();
    
    /**
     * ιߤޤ
     */
    void lockList();

    /**
     * ιΰߤޤ
     */
    void unlockList();

private:
    /**
     * Ʊѥߥ塼ƥå
     */
    Glib::Mutex m_cMutex;
    
    /**
     * 桼̾ΰ
     */
    std::list<Glib::ustring> m_cUserName;
    
    /**
     * ۥ̾ΰ
     */
    std::list<Glib::ustring> m_cHostName;
    
    /**
     * IPɥ쥹ΰ
     */
    std::list<Glib::ustring> m_cIPAddr;
};

#endif

==> fusenshi-0.8.2.tgz: fusenshi-0.8.2/src/include/serverlist.h <==
/*
 * $Id: serverlist.h,v 1.2 2005/12/02 07:08:01 ozawa Exp $
 *
 * Copyright 2003- ONGS Inc. All rights reserved.
 * 
 * author: Masanori OZAWA (ozawa@ongs.co.jp)
 * version: $Revision: 1.2 $
 *
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions
 * are met:
 * 
 *   1. Redistributions of source code must retain the above copyright
 *      notice, this list of conditions and the following disclaimer.
 *   2. Redistributions in binary form must reproduce the above copyright
 *      notice, this list of conditions and the following disclaimer in the
 *      documentation and/or other materials provided with the distribution.
 * 
 * THIS SOFTWARE IS PROVIDED BY ONGS INC ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL ONGS INC OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 * The views and conclusions contained in the software and documentation are
 * those of the authors and should not be interpreted as representing official
 * policies, either expressed or implied, of the ONGS Inc.
 * 
 */

#ifndef ___SERVERLIST_H
#define ___SERVERLIST_H

#include "glib.h"

class ServerList {
public:
    /**
     * 󥹥ȥ饯
     */
    ServerList();

    /**
     * ǥȥ饯
     */
    ~ServerList();
    
    /**
     * ˥оɲäޤ
     * 
     * @param szUserName 桼̾
     * @param szHostName ۥ̾
     * @param szIPAddr  IPɥ쥹
     * @param nExtInfo  Фγĥ
     */
    void add(Glib::ustring szUserName, Glib::ustring szHostName,
             Glib::ustring szIPAddr, u_int32_t nExtInfo);
    
    /**
     * ޤ
     */
    void clear();
    
    /**
     * 桼̾ΰޤ
     */
    std::list<Glib::ustring>& getUserNameList();
    
    /**
     * ۥ̾ΰޤ
     */
    std::list<Glib::ustring>& getHostNameList();
    
    /**
     * IPɥ쥹ΰޤ
     */
    std::list<Glib::ustring>& getIPAddrList();
    
    /**
     * Фγĥΰޤ
     */
    std::list<u_int32_t>& getExtInfoList();
    
    /**
     * ιߤޤ
     */
    void lockList();

    /**
     * ιΰߤޤ
     */
    void unlockList();

private:
    /**
     * Ʊѥߥ塼ƥå
     */
    Glib::Mutex m_cMutex;
    
    /**
     * 桼̾ΰ
     */
    std::list<Glib::ustring> m_cUserName;
    
    /**
     * ۥ̾ΰ
     */
    std::list<Glib::ustring> m_cHostName;
    
    /**
     * IPɥ쥹ΰ
     */
    std::list<Glib::ustring> m_cIPAddr;
    
    /**
     * Фγĥΰ
     */
    std::list<u_int32_t> m_cExtInfo;
};

#endif
